package com.ruoyi.common.typehandler;

import org.apache.ibatis.type.BaseTypeHandler;
import org.apache.ibatis.type.JdbcType;
import org.apache.ibatis.type.MappedJdbcTypes;
import org.apache.ibatis.type.MappedTypes;

import java.sql.CallableStatement;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
//处理用户请求为数组类型 但数据库该字段类型为varchar
@MappedJdbcTypes(JdbcType.VARCHAR)
@MappedTypes(String[].class)
public class StringArrayTypeHandler extends BaseTypeHandler<String[]> {

    @Override
    public void setNonNullParameter(PreparedStatement ps, int i, String[] parameter, JdbcType jdbcType) throws SQLException {
        // 将 String[] 转换为逗号分隔的字符串
        String joinedString = String.join(",", parameter);
        ps.setString(i, joinedString);
    }

    @Override
    public String[] getNullableResult(ResultSet rs, String columnName) throws SQLException {
        // 从数据库中读取字符串并转换为 String[]
        String result = rs.getString(columnName);
        return result != null ? result.split(",") : new String[0];
    }

    @Override
    public String[] getNullableResult(ResultSet rs, int columnIndex) throws SQLException {
        // 从数据库中读取字符串并转换为 String[]
        String result = rs.getString(columnIndex);
        return result != null ? result.split(",") : new String[0];
    }

    @Override
    public String[] getNullableResult(CallableStatement cs, int columnIndex) throws SQLException {
        // 从数据库中读取字符串并转换为 String[]
        String result = cs.getString(columnIndex);
        return result != null ? result.split(",") : new String[0];
    }
}