package com.ruoyi.common.utils;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.atomic.AtomicInteger;

public class ProjectNumberGenerator {

    // 存储当天每种类型的项目计数器
    private static final ConcurrentHashMap<String, AtomicInteger> PROJECT_COUNTER = new ConcurrentHashMap<>();

    /**
     * 生成项目编号
     *
     * @param type 项目类型 (KF RL YW PX PT LZ )
     * @return 生成的项目编号
     */
    public static String generateProjectNumber(String type) {

        String currentDate = LocalDate.now().format(DateTimeFormatter.ofPattern("yyyyMMdd"));
        // 用于区分不同类型的项目
        String key = currentDate + type;
        // 如果该类型今天没有生成过编号，则初始化计数器为 1
        PROJECT_COUNTER.computeIfAbsent(key, k -> new AtomicInteger(1));
        // 获取当前计数器值并递增
        int count = PROJECT_COUNTER.get(key).getAndIncrement();
        // 格式化序号为三位数
        String formattedCount = String.format("%03d", count);
        return currentDate + type + formattedCount;
    }

}
